**greenws** provides an implementation of websockets (`RFC 6455`_) for the
gevent_ networking library. It is backed by the excellent wsproto_ protocol
implementation.

Documentation
-------------

Available on RTD_.

Usage
-----

Don't. Not yet, at least: there's still a lot of work left to do: passing the
Autobahn compliance tests and a nicer client API are the current priorities.

.. _RFC 6455: https://datatracker.ietf.org/doc/html/rfc6455
.. _gevent: https://gevent.org/
.. _wsproto: https://github.com/python-hyper/wsproto
.. _RTD: https://greenws.rtfd.io/
